@@ -5,6 +5,4 @@ class Site(nm.Site):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = (
-            f"https://nmonesource.com/nmos/nmca/en/nav_date.do?{self.IFRAME}"
-        )
+        self.url = f"https://nmonesource.com/nmos/nmca/en/{self.year}/nav_date.do?iframe=true"
