@@ -11,6 +11,6 @@ from juriscraper.opinions.united_states.state import tex
 
 class Site(tex.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.court_name = "capp_8"
