@@ -1,3 +1,4 @@
+from .appellate_attachment_page import AppellateAttachmentPage
 from .appellate_docket import AppellateDocketReport
 from .attachment_page import AttachmentPage
 from .case_query import CaseQuery
@@ -17,6 +18,7 @@ from .rss_feeds import PacerRssFeed
 __all__ = [
     AppellateDocketReport,
     AttachmentPage,
+    AppellateAttachmentPage,
     CaseQuery,
     CaseQueryAdvancedBankruptcy,
     ClaimsRegister,
